@@ -371,7 +371,9 @@ void ProcessList_sort(ProcessList* this) {
       // Take PID 1 as root and add to the new listing
       int vsize = Vector_size(this->processes);
       Process* init = (Process*) (Vector_take(this->processes, 0));
-      assert(init->pid == 1);
+      // This assertion crashes on hardened kernels.
+      // I wonder how well tree view works on those systems.
+      // assert(init->pid == 1);
       init->indent = 0;
       Vector_add(this->processes2, init);
       // Recursively empty list
@@ -565,10 +567,6 @@ static bool ProcessList_processEntries(ProcessList* this, char* dirname, Process
             process->tgid = parent->pid;
          }
 
-         #ifdef HAVE_TASKSTATS        
-         ProcessList_readIoFile(this, process, dirname, name);
-         #endif
-
          if (showUserlandThreads && (!parent || pid != parent->pid)) {
             char subdirname[MAX_NAME+1];
             snprintf(subdirname, MAX_NAME, "%s/%s/task", dirname, name);
@@ -577,6 +575,10 @@ static bool ProcessList_processEntries(ProcessList* this, char* dirname, Process
                continue;
          }
 
+         #ifdef HAVE_TASKSTATS        
+         ProcessList_readIoFile(this, process, dirname, name);
+         #endif
+
          process->updated = true;
 
          if (!existingProcess)
@@ -639,6 +641,40 @@ static bool ProcessList_processEntries(ProcessList* this, char* dirname, Process
                fclose(status);
             }
             #endif
+
+            #ifdef HAVE_VSERVER
+            snprintf(statusfilename, MAX_NAME, "%s/%s/status", dirname, name);
+            status = ProcessList_fopen(this, statusfilename, "r");
+            if (status == NULL) 
+               goto errorReadingProcess;
+            else {
+               char buffer[256];
+               process->vxid = 0;
+               while (!feof(status)) {
+                  char* ok = fgets(buffer, 255, status);
+                  if (!ok)
+                     break;
+
+                  if (String_startsWith(buffer, "VxID:")) {
+                     int vxid;
+                     int ok = ProcessList_read(this, buffer, "VxID:\t%d", &vxid);
+                     if (ok >= 1) {
+                        process->vxid = vxid;
+                     }
+                  }
+                  #if defined HAVE_ANCIENT_VSERVER
+                  else if (String_startsWith(buffer, "s_context:")) {
+                     int vxid;
+                     int ok = ProcessList_read(this, buffer, "s_context:\t%d", &vxid);
+                     if (ok >= 1) {
+                        process->vxid = vxid;
+                     }
+                  }
+                  #endif
+               }
+               fclose(status);
+            }
+            #endif
  
             snprintf(statusfilename, MAX_NAME, "%s/%s/cmdline", dirname, name);
             status = ProcessList_fopen(this, statusfilename, "r");
