@@ -18,6 +18,24 @@ int TasksMeter_attributes[] = {
    TASKS_RUNNING
 };
 
+static void TasksMeter_setValues(Meter* this, char* buffer, int len) {
+   this->total = this->pl->totalTasks;
+   this->values[0] = this->pl->runningTasks;
+   snprintf(buffer, len, "%d/%d", (int) this->values[0], (int) this->total);
+}
+
+static void TasksMeter_display(Object* cast, RichString* out) {
+   Meter* this = (Meter*)cast;
+   RichString_init(out);
+   char buffer[20];
+   sprintf(buffer, "%d", (int)this->total);
+   RichString_append(out, CRT_colors[METER_VALUE], buffer);
+   RichString_append(out, CRT_colors[METER_TEXT], " total, ");
+   sprintf(buffer, "%d", (int)this->values[0]);
+   RichString_append(out, CRT_colors[TASKS_RUNNING], buffer);
+   RichString_append(out, CRT_colors[METER_TEXT], " running");
+}
+
 MeterType TasksMeter = {
    .setValues = TasksMeter_setValues, 
    .display = TasksMeter_display,
@@ -29,21 +47,3 @@ MeterType TasksMeter = {
    .uiName = "Task counter",
    .caption = "Tasks: "
 };
-
-void TasksMeter_setValues(Meter* this, char* buffer, int len) {
-   this->total = this->pl->totalTasks;
-   this->values[0] = this->pl->runningTasks;
-   snprintf(buffer, len, "%d/%d", (int) this->values[0], (int) this->total);
-}
-
-void TasksMeter_display(Object* cast, RichString* out) {
-   Meter* this = (Meter*)cast;
-   RichString_init(out);
-   char buffer[20];
-   sprintf(buffer, "%d", (int)this->total);
-   RichString_append(out, CRT_colors[METER_VALUE], buffer);
-   RichString_append(out, CRT_colors[METER_TEXT], " total, ");
-   sprintf(buffer, "%d", (int)this->values[0]);
-   RichString_append(out, CRT_colors[TASKS_RUNNING], buffer);
-   RichString_append(out, CRT_colors[METER_TEXT], " running");
-}
